//+--------------------------------------------------------------------------+
//|                                                                          |
//|                                WinLIFT.h                                 |
//|                                                                          |
//|             WinLIFT simplified API constants and declarations.           |
//|                                                                          |
//|                               Version 4.85                               |
//|                                                                          |
//+--------------------------------------------------------------------------+
//|                                                                          |
//|                         Author Patrice TERRIER                           |
//|            8 Domaine de Rochagnon. 38800 Champagnier  FRANCE             |
//|                       http://www.zapsolution.com                         |
//|                    E-mail: pterrier@zapsolution.com                      |
//|                                                                          |
//|                   copyright (c) 2010 Patrice TERRIER                     |
//|                                                                          |
//+--------------------------------------------------------------------------+
//|          C++ translation started on : 08-03-2010                         |
//|                        Last revised : 08-04-2010                         |
//+--------------------------------------------------------------------------+

#include <windows.h>
//
#include <iostream>
#include <string.h>

#define WM_SKGETMENUICON (WM_USER + WM_GETICON)

// Anchor constants
#define ANCHOR_NONE                0
#define ANCHOR_LEFT                ANCHOR_NONE
#define ANCHOR_WIDTH               1
#define ANCHOR_RIGHT               2
#define ANCHOR_CENTER_HORZ         3
#define ANCHOR_HEIGHT              4
#define ANCHOR_HEIGHT_WIDTH        5
#define ANCHOR_HEIGHT_RIGHT        6
#define ANCHOR_BOTTOM              7
#define ANCHOR_BOTTOM_WIDTH        8
#define ANCHOR_BOTTOM_RIGHT        9
#define ANCHOR_CENTER_HORZ_BOTTOM  10
#define ANCHOR_CENTER_VERT         11
#define ANCHOR_CENTER_VERT_RIGHT   12
#define ANCHOR_CENTER              13

#define SK_DWM_LEFT                27
#define SK_DWM_TOP                 28
#define SK_DWM_RIGHT               29
#define SK_DWM_BOTTOM              30

#define FontStyleRegular           0
#define FontStyleBold              1
#define FontStyleItalic            2
#define FontStyleBoldItalic        3
#define FontStyleUnderline         4
#define FontStyleStrikeout         8

// Use this value in the optional GMToffset parameter to disable local timer in case of animated background.
#define DISABLE_TIMER              99

HMODULE g_WinLIFT_DLL;

// Init the WinLIFT SkinEngine.
// This function must be the first WinLIFT call.
int skInitEngine(
    std::string skinfile,       // Full path to the Skin theme.
    std::string suserkey        // Private user key to unlock the DLL.
    ) {

    int nRet = 0;

    if (!g_WinLIFT_DLL)
        g_WinLIFT_DLL = LoadLibrary(L"WinLIFT");

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (char*, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skInitEngine");
        if (hPROC) {
            nRet = hPROC((char*) skinfile.c_str(), (char*) suserkey.c_str());
        }
        else {
            FreeLibrary(g_WinLIFT_DLL);
        }
    }
    return nRet;
}

// The main function to skin a window.
int skSkinWindow(
    HWND hWnd,                  // Handle of the poup window to apply the skin theme.
    std::string sbuttontip      // string to build the system button tooltips. 
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (HWND, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSkinWindow");
        if (hPROC) {
            nRet = hPROC(hWnd, (char*) sbuttontip.c_str());
        }
    }
    return nRet;
}

// Disable skinning of a specific control.
int skSkinDisable(
    HWND hCtrl                  // The control handle.
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSkinDisable");
        if (hPROC) {
            nRet = hPROC(hCtrl);
        }
    }
    return nRet;
}

// Enable skinning of a specific control (use it only after a previous call to skSkinDisable).
int skSkinEnable(
    HWND hCtrl                  // The control handle.
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSkinEnable");
        if (hPROC) {
            nRet = hPROC(hCtrl);
        }
    }
    return nRet;
}

// Return the "Skin" author name and copyright.
string skAuthor (
    ) {

    std::string sText;

    if (g_WinLIFT_DLL) {
        typedef char* (__stdcall *zProc) ();
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skAuthor");
        if (hPROC) {
            sText = hPROC();
        }
    }
    return sText;
}

// Return the internal version number.
string skVersion (
    ) {

    std::string sText;

    if (g_WinLIFT_DLL) {
        typedef char* (__stdcall *zProc) ();
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skVersion");
        if (hPROC) {
            sText = hPROC();
        }
    }
  return sText;
}

// Return the skin folder full path, completed with a trailing back slash.
string skSkinFolder (
    ) {

    std::string sText;

    if (g_WinLIFT_DLL) {
        typedef char* (__stdcall *zProc) ();
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSkinFolder");
        if (hPROC) {
            sText = hPROC();
        }
    }
    return sText;
}

// Anchor child controls.
int skSetAnchorCtrl( 
    HWND hCtrl,                 // Handle of the control to anchor.
    int AnchorMode              // Anchor constant.
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (HWND, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSetAnchorCtrl");
        if (hPROC) {
            nRet = hPROC(hCtrl, AnchorMode);
        }
    }
    return nRet;
}

// Animated clock control.
HWND skClockCtrl (
    HWND hOwner,                // Handle of the window parent owner.
    std::string sImageFile,     // Full path name to the clock image background.
    int x,                      // X location of the clock control.
    int y,                      // Y location of the clock control.
    int w,                      // Width of the clock control.
    int h,                      // Height of the clock control.
    int ButID,                  // Unique ID of the clock control.
    int ARGB1,                  // The color to draw the Hour/Minute hands.
    int ARGB2,                  // The color to draw the second hands.
    int GMToffset ) {           // The GMT offset to be used.

    HWND hCtrl = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (__in HWND, char*, int, int, int, int, int, int, int, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skClockCtrl");
        if (hPROC) {
            hCtrl = (HWND) hPROC(hOwner, (char*) sImageFile.c_str(), x, y, w, h, ButID, ARGB1, ARGB2, GMToffset);
        }
    }
    return hCtrl;    
}

// Create Tooltip.
HWND skCreateToolTip (
    HWND hCtrl,                      // Handle of the child control.
    std::string sText) {             // The text to display.

    HWND hTooltip = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skCreateToolTip");
        if (hPROC) {
            hCtrl = hPROC(hCtrl, (char*) sText.c_str());
        }
    }
    return hCtrl;
}

// Assign new tooltip text to control.
void skSetToolTipText (
    HWND hCtrl,                      // Handle of the child control.
    std::string sText) {             // The new text to display.

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSetToolTip");
        if (hPROC) {
            hPROC(hCtrl, (char*) sText.c_str());
        }
    }
}

// Get the tooltip text of a specific control.
string skGetToolTipText (
    HWND hCtrl) {                    // Handle of the child control.

    std::string sText;

    if (g_WinLIFT_DLL) {
        typedef char* (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGetToolTipText");
        if (hPROC) {
            sText = hPROC(hCtrl);
        }
    }
    return sText;
}

// Create a knob control.
HWND skKnobGauge ( 
    HWND hOwner,                     // Handle of the window parent owner.
    std::string sImageFile,          // Full path name to the gauge image.
    int x,                           // X location of the gauge control.
    int y,                           // Y location of the gauge control.
    int w,                           // Width of the gauge control.
    int h,                           // Height of the gauge control.
    int ButID,                       // Unique ID of the gauge control.
    int MinValue,                    // MAXIMUM range value (the exclusion zone is between the MINIMUM and MAXIMUM range).
    int MaxValue,                    // MAXIMUM range value (the exclusion zone is between the MINIMUM and MAXIMUM range).
    int UsePos,                      // 0 or initial angle value in degree to use.
    int Reserved                     // Must be NULL.
    ) {

    HWND hCtrl = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND, char*, int, int, int, int, int, int, int, int, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skKnobGauge");
        if (hPROC) {
            hCtrl = hPROC(hOwner, (char*) sImageFile.c_str(), x, y, w, h, ButID, MinValue, MaxValue, UsePos, Reserved);
        }
    }
    return hCtrl;    
}

// Assign the Min/Max gauge value.
void skGaugeSetMinMax (
    HWND hCtrl,                      // The control handle.
    int nMin,                        // Minimum value (for knob this must be a rotation angle in the range 0-359).
    int nMax                         // Maximum value (for knob this must be a rotation angle in the range 0-359).
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, LONG, LONG);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGaugeSetMinMax");
        if (hPROC) {
            hPROC(hCtrl, nMin, nMax);
        }
    }
}

// Retrieve the Min/Max gauge value (passage by reference).
void skGaugeGetMinMax (
    HWND hCtrl,                      // The control handle.
    int &nMin,                       // Minimum value (for knob this is a rotation angle in the range 0-359).
    int &nMax                        // Maximum value (for knob this is a rotation angle in the range 0-359).
    ) {

    nMin = 0, nMax = 0;
    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, int*, int*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGaugeGetMinMax");
        if (hPROC) {
            hPROC(hCtrl, &nMin, &nMax); // Passage by reference.
        }
    }
}

// Set the gauge value.
void skGaugeSetPos (
    HWND hCtrl,                      // The control handle.
    int nPos,                        // The pos value to set (must be an angle in the range 0-359 for Knob control).
    int RedrawFlag                   // Redraw boolean flag.
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, int, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGaugeSetPos");
        if (hPROC) {
            hPROC(hCtrl, nPos, RedrawFlag);
        }
    }
}

// Get the gauge value.
int skGaugeGetPos ( 
    HWND hCtrl                       // The control handle.
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGaugeGetPos");
        if (hPROC) {
            nRet = hPROC(hCtrl);
        }
    }
    return nRet;
}

// Create a button from a 5-state image.
HWND skButtonImage ( 
    HWND hOwner,            // Handle of the window parent owner.
    std::string sImageFile, // Full path name to the button image.
    int x,                  // X location of the button.
    int y,                  // Y location of the button.
    int ButID,              // Unique ID of the button.
    int StateMax            // Number of state of the button image.
    ) {

    HWND hCtrl = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND, char*, int, int, int, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skButtonImage");
        if (hPROC) {
            hCtrl = hPROC(hOwner, (char*) sImageFile.c_str(), x, y, ButID, StateMax);
        }
    }
    return hCtrl;    
}

// Draw a frame border.
HWND skBorder ( 
    HWND hOwner,            // Handle of the child control.
    int x,                  // X location of the border.
    int y,                  // Y location of the border.
    int w,                  // Width of the border.
    int h,                  // Height of the border.
    int BorderID,           // Unique ID of the border control.
    int UseBorderSize       // Size of the border.
    ) {

    HWND hCtrl = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND, int, int, int, int, int, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skBorder");
        if (hPROC) {
            hCtrl = hPROC(hOwner, x, y, w, h, BorderID, UseBorderSize);
        }
    }
    return hCtrl;    
}

// Create a themed button using an icon and a label.
HWND skPushButtonImage ( 
    HWND hOwner,            // Handle of the window parent owner.
    std::string sImageFile, // Full path name to the icon-image shown on the themed button.
    std::string sLabel,     // The text label of the button.
    int x,                  // X location of the button.
    int y,                  // Y location of the button.
    int w,                  // Width of the button.
    int h,                  // Height of the button.
    int UseID,              // Unique ID of the button.
    int nAlignment          // Button style alignment (BS_LEFT, BS_RIGHT, BS_CENTER, BS_TOP, BS_BOTTOM).
    ) {

    HWND hCtrl = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND, char*, char*, int, int, int, int, int, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skPushButtonImage");
        if (hPROC) {
            hCtrl = hPROC(hOwner, (char*) sImageFile.c_str(), (char*) sLabel.c_str(), x, y, w, h, UseID, nAlignment);
        }
    }
    return hCtrl;    
}

// Paint a static image anywhere hover the skinned window, and under all other child controls.
HWND skStaticImage ( 
    HWND hOwner,            // Handle of the window parent owner.
    std::string sImageFile, // Full path name to the static image.
    int x,                  // X location of the static image control.
    int y,                  // Y location of the static image control.
    int w,                  // Width of the static image control.
    int h,                  // Height of the static image control.
    int UseID               // Unique ID of the static image control.
    ) {

    HWND hCtrl = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND, char*, int, int, int, int, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skStaticImage");
        if (hPROC) {
            hCtrl = hPROC(hOwner, (char*) sImageFile.c_str(), x, y, w, h, UseID);
        }
    }
    return hCtrl;    
}

// Create a full ARGB color (with alpha channel).
int skARGB ( 
    BYTE A,             // Alpha channel in the range 0-255 (0 full transparency, 255 full opaque mode).
    BYTE R,             // Red channel in the range 0-255.
    BYTE G,             // Green channel in the range 0-255.
    BYTE B              // Blue channel in the range 0-255.
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (BYTE, BYTE, BYTE, BYTE);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skARGB");
        if (hPROC) {
            nRet = hPROC(A, R, G, B);
        }
    }
    return nRet;
}

//****************************************************************************
//*                THESE MUST BE USED WITH WINLIFT's MENU                    *
//****************************************************************************
// Replace the standard DrawMenuBar API, must be used with WinLIFT's menu.
void skRedrawMenuBar ( 
    HWND hWinliftMenu        // The WinLIFT menu handle.
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skRedrawMenuBar");
        if (hPROC) {
            hPROC(hWinliftMenu);
        }
    }
}

// Note: WinLIFT's menu are not standard menu, thus do not use the standard API GetMenu
// to retrieve a menu handle but the specific skGetMenu below.
// Instead of using skGetMenu you can also save the menu handle in a global variable and then
// use this global variable in lieu of the GetMenu API.
HWND skGetMenu ( 
    HWND hWinliftMenu       // The internal WinLIFT menu handle.
    ) {                     // RETURN: the Windows menu handle.

    HWND hWindowsMenu = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGetMenu");
        if (hPROC) {
            hWindowsMenu = hPROC(hWinliftMenu);
        }
    }
    return hWindowsMenu;
}

// Retrieve the handle of the WinLIFT's menu container
HWND skMenuContainer (
    HWND hWnd               // The parent popup window handle.
    ) {

    HWND hMenuContainer = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skMenuContainer");
        if (hPROC) {
            hMenuContainer = hPROC(hWnd);
        }
    }
    return hMenuContainer;
}
//****************************************************************************
//*                           END OF SKINNED MENU                            *
//****************************************************************************

HWND skCreateDW (
    HWND hParent                // The parent popup window handle.
    ) {

    HWND hCtrl = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skCreateDW");
        if (hPROC) {
            hCtrl = hPROC(hParent);
        }
    }
    return hCtrl; 
}

void skDestroyDW (
    HWND &hDW                   // Handle of the DW window.
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skDestroyDW");
        if (hPROC) {
            hPROC(&hDW);
        }
    }
}

void skDialogAlert ( 
    std::string sCaption,       // Text of the caption.
    std::string sMessage,       // Text of the message.
    std::string sButton         // Text of the button (will be "Ok" if empty).
    ) {                         // RETURN: nothing.

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (char*, char*, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skDialogAlert");
        if (hPROC) {
            hPROC((char*) sCaption.c_str(), (char*) sMessage.c_str(), (char*) sButton.c_str());
        }
    }
}

void skDialogError ( 
    std::string sCaption,       // Text of the caption.
    std::string sMessage,       // Text of the message.
    std::string sButton         // Text of the button (will be "Ok" if empty).
    ) {                         // RETURN: nothing.

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (char*, char*, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skDialogError");
        if (hPROC) {
            hPROC((char*) sCaption.c_str(), (char*) sMessage.c_str(), (char*) sButton.c_str());
        }
    }
}

void skDialogInfo ( 
    std::string sCaption,       // Text of the caption.
    std::string sMessage,       // Text of the message.
    std::string sButton         // Text of the button (will be "Ok" if empty).
    ) {                         // RETURN: nothing.

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (char*, char*, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skDialogInfo");
        if (hPROC) {
            hPROC((char*) sCaption.c_str(), (char*) sMessage.c_str(), (char*) sButton.c_str());
        }
    }
}

int skDialogYesNo ( 
    std::string sCaption,       // Text of the caption.
    std::string sMessage,       // Text of the message.
    std::string sButton         // "@Yes|No", the "@" char means put the focus on this button.
    ) {                         // RETURN: TRUE for Yes, FALSE for No.
    
    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (char*, char*, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skDialogYesNo");
        if (hPROC) {
            nRet = hPROC((char*) sCaption.c_str(), (char*) sMessage.c_str(), (char*) sButton.c_str());
        }
    }
    return nRet;
}

string skDialogInput ( 
    std::string sCaption,       // Text of the caption.
    std::string sMessage,       // Text of the input message.
    std::string sButton         // Text of the button (will be "Ok" if empty).
    ) {                         // RETURN: the text entered by the user.

    std::string sText;

    if (g_WinLIFT_DLL) {
        typedef char* (__stdcall *zProc) (char*, char*, char*);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skDialogInput");
        if (hPROC) {
            sText = hPROC((char*) sCaption.c_str(), (char*) sMessage.c_str(), (char*) sButton.c_str());
        }
    }
    return sText;
}

// Return the theme caption font handle.
int skCaptionFont (
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) ();
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skCaptionFont");
        if (hPROC) {
            nRet = hPROC();
        }
    }
    return nRet;
}

// Return the theme standard font handle.
int skFont (
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) ();
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skFont");
        if (hPROC) {
            nRet = hPROC();
        }
    }
    return nRet;
}

// return the theme bold font handle.
int skFontBold (
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) ();
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skFontBold");
        if (hPROC) {
            nRet = hPROC();
        }
    }
    return nRet;
}

// Return the theme font handle being used in popup dialog.
int skFontDlg (
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) ();
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skFontDlg");
        if (hPROC) {
            nRet = hPROC();
        }
    }
    return nRet;
}

// To skin a child control on the fly, must be used AFTER the initial call to skInitEngine.
void skSkinChildCtrl ( 
    HWND hCtrl,                 // The handle of the child control.
    int RedrawFlag              // Redraw boolean flag.
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSkinChildCtrl");
        if (hPROC) {
            hPROC(hCtrl, RedrawFlag);
        }
    }
}

// Use this when new controls are added AFTER the initial skinning of the main window.
void skSkinWindowUpdate ( 
    HWND hWnd,                  // The main window handle.
    int RedrawFlag              // Redraw boolean flag.
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSkinWindowUpdate");
        if (hPROC) {
            hPROC(hWnd, RedrawFlag);
        }
    }
}

// This API is to be used only with STATIC and BUTTON controls exclusively!
void skSetLabelFont ( 
    HWND hCtrl,                 // The control handle.
    string sFontName,           // The GDI+ compatible font name to use.
    unsigned short nSize,       // The font size in pixel.
    int ARGBcolor,              // The ARGB color (use the skARGB() function above, or NULL to apply the skin theme color).
    unsigned short nStyle       // One of the FontStyle constant above.       
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, char*, WORD, int, WORD);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSetLabelFont");
        if (hPROC) {
            hPROC(hCtrl, (char*) sFontName.c_str(), nSize, ARGBcolor, nStyle);
        }
    }
}

void skSetZorder ( 
    HWND hCtrl,                 // Handle of the child control.
    int UseOrder                // HWND constant or another child control handle.
    ) {

    if (g_WinLIFT_DLL) {
        typedef void (__stdcall *zProc) (HWND, int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skSetZorder");
        if (hPROC) {
            hPROC(hCtrl, UseOrder);
        }
    }
}

int skGetSystemMetrics ( 
    int nMeasure                // The measure to retrieve.
    ) {

    int nRet = 0;

    if (g_WinLIFT_DLL) {
        typedef int (__stdcall *zProc) (int);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGetSystemMetrics");
        if (hPROC) {
            nRet = hPROC(nMeasure);
        }
    }
    return nRet;
}

HWND skGetDWMregion ( 
    HWND hOwner                 // Handle of the window parent owner.
    ) {

    HWND hRgn = 0;

    if (g_WinLIFT_DLL) {
        typedef HWND (__stdcall *zProc) (HWND);
        zProc hPROC = (zProc) GetProcAddress(g_WinLIFT_DLL, "skGetDWMregion");
        if (hPROC) {
            hRgn = hPROC(hOwner);
        }
    }
    return hRgn;
}
